@@ -2,14 +2,15 @@
 #define CONTOURPY_LINE_TYPE_H
 
 #include <iosfwd>
+#include <string>
 
 // C++11 scoped enum, must be fully qualified to use.
 enum class LineType
 {
     Separate = 101,
-    SeparateCodes = 102,
-    ChunkCombinedCodes = 103,
-    ChunkCombinedOffsets = 104,
+    SeparateCode = 102,
+    ChunkCombinedCode = 103,
+    ChunkCombinedOffset= 104,
 };
 
 std::ostream &operator<<(std::ostream &os, const LineType& line_type);
