@@ -1,22 +1,16 @@
 #ifndef CONTOURPY_MPL_2005_H
 #define CONTOURPY_MPL_2005_H
 
-#include "common.h"
+#include "contour_generator.h"
 #include "mpl2005_original.h"
 
-class Mpl2005ContourGenerator
+class Mpl2005ContourGenerator : public ContourGenerator
 {
 public:
     Mpl2005ContourGenerator(
         const CoordinateArray& x, const CoordinateArray& y, const CoordinateArray& z,
         const MaskArray& mask, index_t x_chunk_size, index_t y_chunk_size);
 
-    // Non-copyable and non-moveable.
-    Mpl2005ContourGenerator(const Mpl2005ContourGenerator& other) = delete;
-    Mpl2005ContourGenerator(const Mpl2005ContourGenerator&& other) = delete;
-    Mpl2005ContourGenerator& operator=(const Mpl2005ContourGenerator& other) = delete;
-    Mpl2005ContourGenerator& operator=(const Mpl2005ContourGenerator&& other) = delete;
-
     ~Mpl2005ContourGenerator();
 
     py::tuple filled(const double& lower_level, const double& upper_level);
@@ -28,7 +22,6 @@ public:
 
 private:
     CoordinateArray _x, _y, _z;
-    MaskArray _mask;
     Csite *_site;
 };
 
